window.Gleam.initSearch([{"doc":"glint","title":"glint","content":"# glint\n\n[![Hex Package](https://img.shields.io/hexpm/v/glint?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/glint)\n[![Hex.pm](https://img.shields.io/hexpm/dt/glint?color=ffaff3)](https://hex.pm/packages/glint)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/glint/)\n[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/tanklesxl/glint/main)](https://github.com/tanklesxl/glint/actions)\n\nGleam command line argument parsing with basic flag support.\n\n## Installation\n\nTo install from hex:\n\n```sh\ngleam add glint\n```\n\n## Usage\n\n### Glint&#39;s Core\n\n`glint` is conceptually quite small, your general flow will be:\n\n1. create a new glint instance with `glint.new`\n1. configure it with `glint.with_pretty_help` and other configuration functions\n1. add commands with `glint.add`\n   1. create a new command with `glint.cmd`\n   1. assign that command any flags required\n   1. assign the command a custom description\n1. run your cli with `glnt.run`, run with a function to handle command output with `glint.run_and_handle`\n\n## ✨ Complementary packages\n\nGlint works amazingly with these other packages:\n\n- [argv](https://github.com/lpil/argv), use this for cross-platform argument fetching\n- [gleescript](https://github.com/lpil/gleescript), use this to generate erlang escripts for your applications\n\n## Mini Example\n\nYou can import `glint` as a dependency and use it to build simple command-line applications like the following simplified version of the [the hello world example](https://github.com/TanklesXL/glint/tree/main/examples/hello/README.md)\n\n```gleam\n// stdlib imports\nimport gleam/io\nimport gleam/list\nimport gleam/result\nimport gleam/string.{uppercase}\n// external dep imports\nimport snag\nimport argv\n// glint imports\nimport glint\nimport glint/flag\n\n/// the key for the caps flag\nconst caps = &quot;caps&quot;\n\n/// a boolean flag with default False to control message capitalization.\n///\nfn caps_flag() -&gt; flag.FlagBuilder(Bool) {\n  flag.bool()\n  |&gt; flag.default(False)\n  |&gt; flag.description(&quot;Capitalize the provided name&quot;)\n}\n\n/// the command function that will be executed\n///\nfn hello(input: glint.CommandInput) -&gt; Nil {\n  let assert Ok(caps) = flag.get_bool(from: input.flags, for: caps)\n\n  let name =\n    case input.args {\n        [] -&gt; &quot;Joe&quot;\n        [name,..] -&gt; name\n    }\n\n  let msg = &quot;Hello, &quot; &lt;&gt; name &lt;&gt; &quot;!&quot;\n\n\n  case caps {\n    True -&gt; uppercase(msg)\n    False -&gt; msg\n  }\n  |&gt; io.println\n}\n\npub fn main() {\n  // create a new glint instance\n  glint.new()\n  // with an app name of &quot;hello&quot;, this is used when printing help text\n  |&gt; glint.with_name(&quot;hello&quot;)\n  // with pretty help enabled, using the built-in colours\n  |&gt; glint.with_pretty_help(glint.default_pretty_help())\n  // with a root command that executes the `hello` function\n  |&gt; glint.add(\n      // add the command to the root\n      at: [],\n      // create the command, add any flags\n      do: glint.command(hello)\n      // with flag `caps`\n      |&gt; glint.flag(caps, caps_flag())\n      // with a short description\n      |&gt; glint.description(&quot;Prints Hello, &lt;NAME&gt;!&quot;),\n  )\n  |&gt; glint.run(argv.load().arguments)\n}\n```\n","url":"index.html"},{"doc":"glint/flag/constraint","title":"Constraint","content":"pub type Constraint(a) =\n  fn(a) -&gt; Result(Nil)\n Constraint type for verifying flag values\n\n\nSynonyms:\nglint/flag/constraint.Constraint\nglint/flag/constraint Constraint","url":"glint/flag/constraint.html#Constraint"},{"doc":"glint/flag/constraint","title":"each","content":"pub fn each(\n  constraint: fn(a) -&gt; Result(Nil, Snag),\n) -&gt; fn(List(a)) -&gt; Result(Nil, Snag)\n each is a convenience function for applying a Constraint(a) to a List(a).\n This is useful because the default behaviour for constraints on lists is that they will apply to the list as a whole.\n \n For example, to apply one_of to all items in a `List(Int)`:\n \n [1, 2, 3, 4] |&gt; one_of |&gt; each\n \nSynonyms:\nglint/flag/constraint.each\nglint/flag/constraint each","url":"glint/flag/constraint.html#each"},{"doc":"glint/flag/constraint","title":"none_of","content":"pub fn none_of(disallowed: List(a)) -&gt; fn(a) -&gt; Result(Nil, Snag)\n none_of returns a Constraint that ensures the parsed flag value is not one of the disallowed values.\n\nSynonyms:\nglint/flag/constraint.none_of\nglint/flag/constraint none_of","url":"glint/flag/constraint.html#none_of"},{"doc":"glint/flag/constraint","title":"one_of","content":"pub fn one_of(allowed: List(a)) -&gt; fn(a) -&gt; Result(Nil, Snag)\n one_of returns a Constraint that ensures the parsed flag value is\n one of the allowed values.\n\nSynonyms:\nglint/flag/constraint.one_of\nglint/flag/constraint one_of","url":"glint/flag/constraint.html#one_of"},{"doc":"glint/flag/constraint","title":"glint/flag/constraint","content":"","url":"glint/flag/constraint.html"},{"doc":"glint/flag","title":"Description","content":"pub type Description =\n  String\n Flag descriptions\n\n\nSynonyms:\nglint/flag.Description\nglint/flag Description","url":"glint/flag.html#Description"},{"doc":"glint/flag","title":"Flag","content":"pub type Flag {\n  Flag(value: Value, description: Description)\n}\n Flag data and descriptions\n\nFlag(value: Value, description: Description)\n\n\nSynonyms:\nglint/flag.Flag\nglint/flag Flag","url":"glint/flag.html#Flag"},{"doc":"glint/flag","title":"FlagBuilder","content":"pub opaque type FlagBuilder(a)\n A type that facilitates the creation of `Flag`s\n\n\nSynonyms:\nglint/flag.FlagBuilder\nglint/flag FlagBuilder","url":"glint/flag.html#FlagBuilder"},{"doc":"glint/flag","title":"Internal","content":"pub opaque type Internal(a)\n An internal representation of flag contents\n\n\nSynonyms:\nglint/flag.Internal\nglint/flag Internal","url":"glint/flag.html#Internal"},{"doc":"glint/flag","title":"Map","content":"pub type Map =\n  dict.Dict(String, Flag)\n Associate flag names to their current values.\n\n\nSynonyms:\nglint/flag.Map\nglint/flag Map","url":"glint/flag.html#Map"},{"doc":"glint/flag","title":"Value","content":"pub type Value {\n  B(Internal(Bool))\n  I(Internal(Int))\n  LI(Internal(List(Int)))\n  F(Internal(Float))\n  LF(Internal(List(Float)))\n  S(Internal(String))\n  LS(Internal(List(String)))\n}\n Supported flag types.\n\nB(Internal(Bool))\n Boolean flags, to be passed in as `--flag=true` or `--flag=false`.\n Can be toggled by omitting the desired value like `--flag`.\n Toggling will negate the existing value.\n\n\nI(Internal(Int))\n Int flags, to be passed in as `--flag=1`\n\n\nLI(Internal(List(Int)))\n List(Int) flags, to be passed in as `--flag=1,2,3`\n\n\nF(Internal(Float))\n Float flags, to be passed in as `--flag=1.0`\n\n\nLF(Internal(List(Float)))\n List(Float) flags, to be passed in as `--flag=1.0,2.0`\n\n\nS(Internal(String))\n String flags, to be passed in as `--flag=hello`\n\n\nLS(Internal(List(String)))\n List(String) flags, to be passed in as `--flag=hello,world`\n\n\nSynonyms:\nglint/flag.Value\nglint/flag Value","url":"glint/flag.html#Value"},{"doc":"glint/flag","title":"prefix","content":"pub const prefix: String = &quot;--&quot;\n Flag inputs must start with this prefix\n\nSynonyms:\nglint/flag.prefix\nglint/flag prefix","url":"glint/flag.html#prefix"},{"doc":"glint/flag","title":"bool","content":"pub fn bool() -&gt; FlagBuilder(Bool)\n initialise a bool flag builder\n \nSynonyms:\nglint/flag.bool\nglint/flag bool","url":"glint/flag.html#bool"},{"doc":"glint/flag","title":"build","content":"pub fn build(fb: FlagBuilder(a)) -&gt; Flag\n convert a FlagBuilder(a) into its corresponding Flag representation\n \nSynonyms:\nglint/flag.build\nglint/flag build","url":"glint/flag.html#build"},{"doc":"glint/flag","title":"build_map","content":"pub fn build_map(\n  flags: List(#(String, Flag)),\n) -&gt; Dict(String, Flag)\n Convert a list of flags to a Map.\n\nSynonyms:\nglint/flag.build_map\nglint/flag build_map","url":"glint/flag.html#build_map"},{"doc":"glint/flag","title":"constraint","content":"pub fn constraint(\n  builder: FlagBuilder(a),\n  constraint: fn(a) -&gt; Result(Nil, Snag),\n) -&gt; FlagBuilder(a)\n attach a constraint to a `Flag`\n\nSynonyms:\nglint/flag.constraint\nglint/flag constraint","url":"glint/flag.html#constraint"},{"doc":"glint/flag","title":"default","content":"pub fn default(\n  for builder: FlagBuilder(a),\n  of default: a,\n) -&gt; FlagBuilder(a)\n Set the default value for a flag `Value`\n\nSynonyms:\nglint/flag.default\nglint/flag default","url":"glint/flag.html#default"},{"doc":"glint/flag","title":"description","content":"pub fn description(\n  for builder: FlagBuilder(a),\n  of description: String,\n) -&gt; FlagBuilder(a)\n attach a description to a `Flag`\n\nSynonyms:\nglint/flag.description\nglint/flag description","url":"glint/flag.html#description"},{"doc":"glint/flag","title":"float","content":"pub fn float() -&gt; FlagBuilder(Float)\n initialise a float flag builder\n\nSynonyms:\nglint/flag.float\nglint/flag float","url":"glint/flag.html#float"},{"doc":"glint/flag","title":"float_list","content":"pub fn float_list() -&gt; FlagBuilder(List(Float))\n initialise a float list flag builder\n\nSynonyms:\nglint/flag.float_list\nglint/flag float_list","url":"glint/flag.html#float_list"},{"doc":"glint/flag","title":"get_bool","content":"pub fn get_bool(\n  from flags: Dict(String, Flag),\n  for name: String,\n) -&gt; Result(Bool, Snag)\n Gets the current value for the associated bool flag\n\nSynonyms:\nglint/flag.get_bool\nglint/flag get_bool","url":"glint/flag.html#get_bool"},{"doc":"glint/flag","title":"get_bool_value","content":"pub fn get_bool_value(from flag: Flag) -&gt; Result(Bool, Snag)\n Gets the current value for the provided bool flag\n\nSynonyms:\nglint/flag.get_bool_value\nglint/flag get_bool_value","url":"glint/flag.html#get_bool_value"},{"doc":"glint/flag","title":"get_float","content":"pub fn get_float(\n  from flags: Dict(String, Flag),\n  for name: String,\n) -&gt; Result(Float, Snag)\n Gets the current value for the associated float flag\n\nSynonyms:\nglint/flag.get_float\nglint/flag get_float","url":"glint/flag.html#get_float"},{"doc":"glint/flag","title":"get_float_value","content":"pub fn get_float_value(from flag: Flag) -&gt; Result(Float, Snag)\n Gets the current value for the provided float flag\n\nSynonyms:\nglint/flag.get_float_value\nglint/flag get_float_value","url":"glint/flag.html#get_float_value"},{"doc":"glint/flag","title":"get_floats","content":"pub fn get_floats(\n  from flags: Dict(String, Flag),\n  for name: String,\n) -&gt; Result(List(Float), Snag)\n Gets the current value for the associated floats flag\n\nSynonyms:\nglint/flag.get_floats\nglint/flag get_floats","url":"glint/flag.html#get_floats"},{"doc":"glint/flag","title":"get_floats_value","content":"pub fn get_floats_value(\n  from flag: Flag,\n) -&gt; Result(List(Float), Snag)\n Gets the current value for the provided floats flag\n\nSynonyms:\nglint/flag.get_floats_value\nglint/flag get_floats_value","url":"glint/flag.html#get_floats_value"},{"doc":"glint/flag","title":"get_int","content":"pub fn get_int(\n  from flags: Dict(String, Flag),\n  for name: String,\n) -&gt; Result(Int, Snag)\n Gets the current value for the associated int flag\n\nSynonyms:\nglint/flag.get_int\nglint/flag get_int","url":"glint/flag.html#get_int"},{"doc":"glint/flag","title":"get_int_value","content":"pub fn get_int_value(from flag: Flag) -&gt; Result(Int, Snag)\n Gets the current value for the provided int flag\n\nSynonyms:\nglint/flag.get_int_value\nglint/flag get_int_value","url":"glint/flag.html#get_int_value"},{"doc":"glint/flag","title":"get_ints","content":"pub fn get_ints(\n  from flags: Dict(String, Flag),\n  for name: String,\n) -&gt; Result(List(Int), Snag)\n Gets the current value for the associated ints flag\n\nSynonyms:\nglint/flag.get_ints\nglint/flag get_ints","url":"glint/flag.html#get_ints"},{"doc":"glint/flag","title":"get_ints_value","content":"pub fn get_ints_value(from flag: Flag) -&gt; Result(List(Int), Snag)\n Gets the current value for the provided ints flag\n\nSynonyms:\nglint/flag.get_ints_value\nglint/flag get_ints_value","url":"glint/flag.html#get_ints_value"},{"doc":"glint/flag","title":"get_string","content":"pub fn get_string(\n  from flags: Dict(String, Flag),\n  for name: String,\n) -&gt; Result(String, Snag)\n Gets the current value for the associated string flag\n\nSynonyms:\nglint/flag.get_string\nglint/flag get_string","url":"glint/flag.html#get_string"},{"doc":"glint/flag","title":"get_string_value","content":"pub fn get_string_value(from flag: Flag) -&gt; Result(String, Snag)\n Gets the current value for the provided string flag\n\nSynonyms:\nglint/flag.get_string_value\nglint/flag get_string_value","url":"glint/flag.html#get_string_value"},{"doc":"glint/flag","title":"get_strings","content":"pub fn get_strings(\n  from flags: Dict(String, Flag),\n  for name: String,\n) -&gt; Result(List(String), Snag)\n Gets the current value for the associated strings flag\n\nSynonyms:\nglint/flag.get_strings\nglint/flag get_strings","url":"glint/flag.html#get_strings"},{"doc":"glint/flag","title":"get_strings_value","content":"pub fn get_strings_value(\n  from flag: Flag,\n) -&gt; Result(List(String), Snag)\n Gets the current value for the provided strings flag\n\nSynonyms:\nglint/flag.get_strings_value\nglint/flag get_strings_value","url":"glint/flag.html#get_strings_value"},{"doc":"glint/flag","title":"int","content":"pub fn int() -&gt; FlagBuilder(Int)\n initialise an int flag builder\n\nSynonyms:\nglint/flag.int\nglint/flag int","url":"glint/flag.html#int"},{"doc":"glint/flag","title":"int_list","content":"pub fn int_list() -&gt; FlagBuilder(List(Int))\n initialise an int list flag builder\n\nSynonyms:\nglint/flag.int_list\nglint/flag int_list","url":"glint/flag.html#int_list"},{"doc":"glint/flag","title":"string","content":"pub fn string() -&gt; FlagBuilder(String)\n initialise a string flag builder\n\nSynonyms:\nglint/flag.string\nglint/flag string","url":"glint/flag.html#string"},{"doc":"glint/flag","title":"string_list","content":"pub fn string_list() -&gt; FlagBuilder(List(String))\n intitialise a string list flag builder\n \nSynonyms:\nglint/flag.string_list\nglint/flag string_list","url":"glint/flag.html#string_list"},{"doc":"glint/flag","title":"update_flags","content":"pub fn update_flags(\n  in flags: Dict(String, Flag),\n  with flag_input: String,\n) -&gt; Result(Dict(String, Flag), Snag)\n Updates a flag value, ensuring that the new value can satisfy the required type.\n Assumes that all flag inputs passed in start with --\n This function is only intended to be used from glint.execute_root\n\nSynonyms:\nglint/flag.update_flags\nglint/flag update_flags","url":"glint/flag.html#update_flags"},{"doc":"glint/flag","title":"glint/flag","content":"","url":"glint/flag.html"},{"doc":"glint","title":"ArgsCount","content":"pub type ArgsCount {\n  EqArgs(Int)\n  MinArgs(Int)\n}\n Specify the expected number of arguments with this type and the `glint.unnamed_args` function\n\nEqArgs(Int)\n Specifies that a command must accept a specific number of arguments\n\n\nMinArgs(Int)\n Specifies that a command must accept a minimum number of arguments\n\n\nSynonyms:\nglint.ArgsCount\nglint ArgsCount","url":"glint.html#ArgsCount"},{"doc":"glint","title":"CmdResult","content":"pub type CmdResult(a) =\n  gleam.Result(Out(a), String)\n Result type for command execution\n\n\nSynonyms:\nglint.CmdResult\nglint CmdResult","url":"glint.html#CmdResult"},{"doc":"glint","title":"Command","content":"pub opaque type Command(a)\n A glint command\n\n\nSynonyms:\nglint.Command\nglint Command","url":"glint.html#Command"},{"doc":"glint","title":"CommandInput","content":"pub type CommandInput {\n  CommandInput(\n    args: List(String),\n    flags: FlagMap,\n    named_args: dict.Dict(String, String),\n  )\n}\n The input type for `Runner`.\n\n Arguments passed to `glint` are provided as the `args` field.\n\n Flags passed to `glint` are provided as the `flags` field.\n\n If named arguments are specified at command creation, they will be accessible via the `named_args` field.\n IMPORTANT: Arguments matched by `named_args` will not be present in the `args` field.\n\nCommandInput(\n  args: List(String),\n  flags: FlagMap,\n  named_args: dict.Dict(String, String),\n)\n\n\nSynonyms:\nglint.CommandInput\nglint CommandInput","url":"glint.html#CommandInput"},{"doc":"glint","title":"Config","content":"pub type Config {\n  Config(\n    pretty_help: Option(PrettyHelp),\n    name: Option(String),\n    as_gleam_module: Bool,\n  )\n}\n Config for glint\n\nConfig(\n  pretty_help: Option(PrettyHelp),\n  name: Option(String),\n  as_gleam_module: Bool,\n)\n\n\nSynonyms:\nglint.Config\nglint Config","url":"glint.html#Config"},{"doc":"glint","title":"Glint","content":"pub opaque type Glint(a)\n Glint container type for config and commands\n\n\nSynonyms:\nglint.Glint\nglint Glint","url":"glint.html#Glint"},{"doc":"glint","title":"Out","content":"pub type Out(a) {\n  Out(a)\n  Help(String)\n}\n Ok type for command execution\n\nOut(a)\n Container for the command return value\n\nHelp(String)\n Container for the generated help string\n\nSynonyms:\nglint.Out\nglint Out","url":"glint.html#Out"},{"doc":"glint","title":"PrettyHelp","content":"pub type PrettyHelp {\n  PrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n}\n PrettyHelp defines the header colours to be used when styling help text\n\nPrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n\n\nSynonyms:\nglint.PrettyHelp\nglint PrettyHelp","url":"glint.html#PrettyHelp"},{"doc":"glint","title":"Runner","content":"pub type Runner(a) =\n  fn(CommandInput) -&gt; a\n Function type to be run by `glint`.\n\n\nSynonyms:\nglint.Runner\nglint Runner","url":"glint.html#Runner"},{"doc":"glint","title":"default_config","content":"pub const default_config: Config = Config(\n  pretty_help: None,\n  name: None,\n  as_gleam_module: False,\n)\n Default config\n\nSynonyms:\nglint.default_config\nglint default_config","url":"glint.html#default_config"},{"doc":"glint","title":"add","content":"pub fn add(\n  to glint: Glint(a),\n  at path: List(String),\n  do contents: Command(a),\n) -&gt; Glint(a)\n Adds a new command to be run at the specified path.\n\n If the path is `[]`, the root command is set with the provided function and\n flags.\n\n Note: all command paths are sanitized by stripping whitespace and removing any empty string elements.\n\nSynonyms:\nglint.add\nglint add","url":"glint.html#add"},{"doc":"glint","title":"as_gleam_module","content":"pub fn as_gleam_module(glint: Glint(a)) -&gt; Glint(a)\n Adjust the generated help text to reflect that the current glint app should be run as a gleam module.\n Use in conjunction with `glint.with_name` to get usage text output like `gleam run -m &lt;name&gt;`\nSynonyms:\nglint.as_gleam_module\nglint as_gleam_module","url":"glint.html#as_gleam_module"},{"doc":"glint","title":"command","content":"pub fn command(do runner: fn(CommandInput) -&gt; a) -&gt; Command(a)\n Create a Command(a) from a Runner(a)\n\nSynonyms:\nglint.command\nglint command","url":"glint.html#command"},{"doc":"glint","title":"default_pretty_help","content":"pub fn default_pretty_help() -&gt; PrettyHelp\n Default pretty help heading colouring\n mint (r: 182, g: 255, b: 234) colour for usage\n pink (r: 255, g: 175, b: 243) colour for flags\n buttercup (r: 252, g: 226, b: 174) colour for subcommands\n\nSynonyms:\nglint.default_pretty_help\nglint default_pretty_help","url":"glint.html#default_pretty_help"},{"doc":"glint","title":"description","content":"pub fn description(\n  cmd: Command(a),\n  description: String,\n) -&gt; Command(a)\n Attach a description to a Command(a)\n\nSynonyms:\nglint.description\nglint description","url":"glint.html#description"},{"doc":"glint","title":"execute","content":"pub fn execute(\n  glint: Glint(a),\n  args: List(String),\n) -&gt; Result(Out(a), String)\n Determines which command to run and executes it.\n\n Sets any provided flags if necessary.\n\n Each value prefixed with `--` is parsed as a flag.\n\n This function does not print its output and is mainly intended for use within `glint` itself.\n If you would like to print or handle the output of a command please see the `run_and_handle` function.\n\nSynonyms:\nglint.execute\nglint execute","url":"glint.html#execute"},{"doc":"glint","title":"flag","content":"pub fn flag(\n  cmd: Command(a),\n  at key: String,\n  of flag: FlagBuilder(b),\n) -&gt; Command(a)\n Add a `flag.Flag` to a `Command`\n\nSynonyms:\nglint.flag\nglint flag","url":"glint.html#flag"},{"doc":"glint","title":"flag_tuple","content":"pub fn flag_tuple(\n  cmd: Command(a),\n  with tup: #(String, FlagBuilder(b)),\n) -&gt; Command(a)\n Add a `flag.Flag to a `Command` when the flag name and builder are bundled as a #(String, flag.FlagBuilder(a)).\n\n This is merely a convenience function and calls `glint.flag` under the hood.\n\nSynonyms:\nglint.flag_tuple\nglint flag_tuple","url":"glint.html#flag_tuple"},{"doc":"glint","title":"flags","content":"pub fn flags(\n  cmd: Command(a),\n  with flags: List(#(String, Flag)),\n) -&gt; Command(a)\n Add multiple `Flag`s to a `Command`, note that this function uses `Flag` and not `FlagBuilder(_)`.\n The user will need to call `flag.build` before providing the flags here.\n\n It is recommended to call `glint.flag` instead.\n\nSynonyms:\nglint.flags\nglint flags","url":"glint.html#flags"},{"doc":"glint","title":"global_flag","content":"pub fn global_flag(\n  glint: Glint(a),\n  at key: String,\n  of flag: FlagBuilder(b),\n) -&gt; Glint(a)\n Add global flags to the existing command tree\n This is the equivalent to calling `glint.group_flag` with a path parameter of `[]`.\n\n\nSynonyms:\nglint.global_flag\nglint global_flag","url":"glint.html#global_flag"},{"doc":"glint","title":"global_flag_tuple","content":"pub fn global_flag_tuple(\n  glint: Glint(a),\n  with tup: #(String, FlagBuilder(b)),\n) -&gt; Glint(a)\n Add global flags to the existing command tree.\n This is the equivalent to calling `glint.group_flag_tuple` with a path parameter of `[]`.\n\nSynonyms:\nglint.global_flag_tuple\nglint global_flag_tuple","url":"glint.html#global_flag_tuple"},{"doc":"glint","title":"global_flags","content":"pub fn global_flags(\n  glint: Glint(a),\n  flags: List(#(String, Flag)),\n) -&gt; Glint(a)\n Add global flags to the existing command tree.\n\n Like `glint.flags`, this function requires `Flag`s insead of `FlagBuilder(_)`.\n This is the equivalent to calling `glint.group_flags` with a path parameter of `[]`.\n\n Note: use of this function requires calling `flag.build` yourself on any `flag.FlagBuilder`s you wish to convert to `flag.Flag`s\n It is recommended to use `glint.global_flag` instead.\n\nSynonyms:\nglint.global_flags\nglint global_flags","url":"glint.html#global_flags"},{"doc":"glint","title":"group_flag","content":"pub fn group_flag(\n  in glint: Glint(a),\n  at path: List(String),\n  for name: String,\n  of flag: FlagBuilder(b),\n) -&gt; Glint(a)\n Add a flag for a group of commands.\n The provided flags will be available to all commands at or beyond the provided path\n\nSynonyms:\nglint.group_flag\nglint group_flag","url":"glint.html#group_flag"},{"doc":"glint","title":"group_flag_tuple","content":"pub fn group_flag_tuple(\n  in glint: Glint(a),\n  at path: List(String),\n  of flag: #(String, FlagBuilder(b)),\n) -&gt; Glint(a)\n Add a flag for a group of commands.\n The provided flags will be available to all commands at or beyond the provided path\n\n This is a convenience function and calls `glint.group_flag` under the hood.\n\nSynonyms:\nglint.group_flag_tuple\nglint group_flag_tuple","url":"glint.html#group_flag_tuple"},{"doc":"glint","title":"group_flags","content":"pub fn group_flags(\n  in glint: Glint(a),\n  at path: List(String),\n  with flags: List(#(String, Flag)),\n) -&gt; Glint(a)\n Add flags for groups of commands.\n It is recommended to use `glint.group_flag` instead if possible\n\n The provided flags will be available to all commands at or beyond the provided path\n\n Note: use of this function requires calling `flag.build` yourself on any `flag.FlagBuilder`s you wish to convert to `flag.Flag`s\n\nSynonyms:\nglint.group_flags\nglint group_flags","url":"glint.html#group_flags"},{"doc":"glint","title":"help_flag","content":"pub fn help_flag() -&gt; String\n Function to create the help flag string\n Exported for testing purposes only\n\nSynonyms:\nglint.help_flag\nglint help_flag","url":"glint.html#help_flag"},{"doc":"glint","title":"named_args","content":"pub fn named_args(\n  cmd: Command(a),\n  args: List(String),\n) -&gt; Command(a)\n Add a list of named arguments to a Command\n These named arguments will be matched with the first N arguments passed to the command\n All named arguments must match for a command to succeed\n This works in combination with CommandInput.named_args which will contain the matched args in a Dict(String,String)\n IMPORTANT: Matched named arguments will not be present in CommandInput.args\n\nSynonyms:\nglint.named_args\nglint named_args","url":"glint.html#named_args"},{"doc":"glint","title":"new","content":"pub fn new() -&gt; Glint(a)\n Creates a new command tree.\n\nSynonyms:\nglint.new\nglint new","url":"glint.html#new"},{"doc":"glint","title":"run","content":"pub fn run(from glint: Glint(a), for args: List(String)) -&gt; Nil\n A wrapper for `execute` that prints any errors enountered or the help text if requested.\n This function ignores any value returned by the command that was run.\n If you would like to do something with the command output please see the run_and_handle function.\n\nSynonyms:\nglint.run\nglint run","url":"glint.html#run"},{"doc":"glint","title":"run_and_handle","content":"pub fn run_and_handle(\n  from glint: Glint(a),\n  for args: List(String),\n  with handle: fn(a) -&gt; b,\n) -&gt; Nil\n A wrapper for `execute` that prints any errors enountered or the help text if requested.\n This function calls the provided handler with the value returned by the command that was run.\n\nSynonyms:\nglint.run_and_handle\nglint run_and_handle","url":"glint.html#run_and_handle"},{"doc":"glint","title":"unnamed_args","content":"pub fn unnamed_args(\n  cmd: Command(a),\n  count: ArgsCount,\n) -&gt; Command(a)\n Specify a specific number of unnamed args that a given command expects\n\nSynonyms:\nglint.unnamed_args\nglint unnamed_args","url":"glint.html#unnamed_args"},{"doc":"glint","title":"with_config","content":"pub fn with_config(glint: Glint(a), config: Config) -&gt; Glint(a)\n Add the provided config to the existing command tree\n\nSynonyms:\nglint.with_config\nglint with_config","url":"glint.html#with_config"},{"doc":"glint","title":"with_name","content":"pub fn with_name(glint: Glint(a), name: String) -&gt; Glint(a)\n Give the current glint application a name\n\nSynonyms:\nglint.with_name\nglint with_name","url":"glint.html#with_name"},{"doc":"glint","title":"with_pretty_help","content":"pub fn with_pretty_help(\n  glint: Glint(a),\n  pretty: PrettyHelp,\n) -&gt; Glint(a)\n Enable custom colours for help text headers\n For a pre-made colouring use `default_pretty_help()`\n\nSynonyms:\nglint.with_pretty_help\nglint with_pretty_help","url":"glint.html#with_pretty_help"},{"doc":"glint","title":"without_pretty_help","content":"pub fn without_pretty_help(glint: Glint(a)) -&gt; Glint(a)\n Disable custom colours for help text headers\n\nSynonyms:\nglint.without_pretty_help\nglint without_pretty_help","url":"glint.html#without_pretty_help"},{"doc":"glint","title":"glint","content":"","url":"glint.html"}]);